@@ -12,8 +12,8 @@ from mstrio.object_management import folder
 import pandas as pd
 #import error_controller
 #from mstrio.utils.error_handlers import ErrorHandler
-from src.mstr_robotics.helper import str_func
-from src.mstr_robotics.logger import logger
+from helper  import str_func
+from logger import logger
 
 str_func=str_func
 log=logger
@@ -26,14 +26,14 @@ def get_conn(self, conn_det, project_id=None):
         if project_id:
             conn.select_project(project_id)
         return conn
-
+"""
     if 'workstationData' in locals():
         print("halloWorsk")
         conn = get_connection(workstationData)
         conn.headers['Content-type'] = "application/json"
         return conn
     return None
-
+"""
 
 class rep:
 
